@@ -19,7 +19,7 @@ SOVER=`sed '2q;d' "$VERSION_FILE"`
 BINDYVER=`sed '3q;d' "$VERSION_FILE"`
 XIWRAPPERVER=`sed '4q;d' "$VERSION_FILE"`
 if [ -z "$XIWRAPPERVER" ] ; then
-	XIWRAPPERVER=default
+	XIWRAPPERVER=main
 fi
 MINIUPNPCVER=8ddbb71
 SOVERMAJOR=`echo $SOVER | sed 's/\..*//'`
@@ -296,7 +296,7 @@ makedist()
 
 	tar -C dist -czf dist/ximc-$VER.tar.gz ximc-$VER
 	tar -C dist -czf dist/ximc-$VER-src.tar.gz ximc-$VER-src
-	cd wrappers/python/dist/ ; tar -cf ../../../dist/python-binding-$VER.tar * ; cd -
+	cd wrappers/python/dist/ ; 7z a ../../../dist/libximc_bindings_python-$VER.7z * ; cd -
 
 	unset COPYFILE_DISABLE
 }
@@ -395,9 +395,7 @@ build_dep_bindy()
 
 build_dep_xiwrapper()
 {
-	if [ -z "$URL_XIWRAPPER" ] ; then
-	  URL_XIWRAPPER="https://gitlab.ximc.ru/ximc-public/libxiwrapper.git"
-	fi
+	URL_XIWRAPPER="https://github.com/Standa-Optomechanics/libxiwrapper.git"
 	echo "--- Building xiwrapper ---"
 	if [ "x$SKIP_DEPS_CHECKOUT" != "xyes" ] ; then
 		rm -rf $DEPS/xiwrapper
@@ -504,8 +502,17 @@ build_osx_impl()
 
 echo XIMC build script
 trap exit_clean_up EXIT INT TERM
-ACTION=$1
-shift
+if [ $# -ge 1 ] ; then
+	ACTION=$1
+	shift
+else
+	echo "\nUsage: $0 {depends | lib | libfast | onlydocs | onlydist | makedist |"
+	echo "   libosx | libdeb | librpm |"
+	echo "   genfwheader | genfwlib | genwikiru | genwikien |"
+	echo "   assemblyprofile | assemblywikipageen | assemblywikipageru |"
+	echo "   clean | cleandist }"
+	exit 1
+fi
 
 # configure env
 if [ "$ACTION" != "cleandist" ] && [ "$ACTION" != "clean" ] ; then
@@ -634,6 +641,7 @@ cleandist)
 	;;
 
 *)
+	echo "\nUnknown command $ACTION.\n"
 	echo "Usage: $0 {depends | lib | libfast | onlydocs | onlydist | makedist |"
 		echo "   libosx | libdeb | librpm |"
 		echo "   genfwheader | genfwlib | genwikiru | genwikien |"
